package de.intevation.artifactdatabase;

import java.io.UnsupportedEncodingException;

import java.util.UUID;

import org.apache.log4j.Logger;

/**
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public final class StringUtils
{
    private static Logger logger = Logger.getLogger(StringUtils.class);

    private static final char [] HEX = {
        '0', '1', '2', '3', '4', '5', '6', '7', 
        '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'
    };

    private StringUtils() {
    }

    public static final String toHex(byte [] bytes) {
        char out [] = new char[bytes.length*2];

        for (int i = 0, j = 0; i < bytes.length; ++i) {
            byte b  = bytes[i];
            out[j++] = HEX[(b >> 4) & 0xf];
            out[j++] = HEX[ b       & 0xf];
        }

        return new String(out);
    }

    public static final String newUUID() {
        return UUID.randomUUID().toString();
    }

    public static final boolean checkUUID(String uuid) {
        try {
            UUID.fromString(uuid);
        }
        catch (IllegalArgumentException iae) {
            logger.warn(iae.getLocalizedMessage());
            return false;
        }
        return true;
    }

    public static final byte [] getUTF8Bytes(String s) {
        try {
            return s.getBytes("UTF-8");
        }
        catch (UnsupportedEncodingException usee) {
            logger.error(usee.getLocalizedMessage(), usee);
            return s.getBytes();
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
